Rust bindings to the ESC/POS printer database.
Structs
- The specific ESC/POS features that are supported by a printer profile.
- Information for a supported ESC/POS font.
- A mapping from a
u8toT. - An iterator over an
IntMap. - Print media information for a printer profile.
- An owned version of
IntMap. - A profile with capability information for an ESC/POS printer.
- The supported print width for a printer profile.
Enums
- An ink color supported by a printer profile.
- A code page supported by ESC/POS printers.
Statics
- AF-240 Customer Display profile
- A map from the name of each profile in the database to its
Profile. - CT-S651 profile
- Default profile
- ITPP047 profile
- KR-306 profile
- Star mcPrint2/mcPrint3 profile
- 80-V-UL profile
- NT-5890K profile
- OCD-100 Customer Display profile
- OCD-300 Customer Display profile
- P822D profile
- POS5890 Series profile
- RP326 profile
- RP-F10 profile
- RP-F10 profile
- Safe profile
- Simple profile
- SP2000 Series profile
- SRP-S300 profile
- Sunmi V2 profile
- TEP200M Series profile
- TH230 profile
- TH230+ profile
- TM-L90 profile
- TM-P80 profile
- TM-P80 (42 column mode) profile
- TM-T20II profile
- TM-T20II (42 column mode) profile
- TM-T88II profile
- TM-T88III profile
- TM-T88IV profile
- TM-T88IV South Asia profile
- TM-T88V profile
- TM-U220 profile
- TM-U220B profile
- TSP600 Series profile
- TUP500 Series profile
- T-1 profile
- ZJ-5870 Thermal Receipt Printer profile