pub struct Features(/* private fields */);Expand description
The specific ESC/POS features that are supported by a printer profile.
Implementations
Sourceimpl Features
impl Features
Sourcepub fn bit_image_column(&self) -> bool
pub fn bit_image_column(&self) -> bool
Check if the bitImageColumn feature is supported.
Sourcepub fn bit_image_raster(&self) -> bool
pub fn bit_image_raster(&self) -> bool
Check if the bitImageRaster feature is supported.
Sourcepub fn high_density(&self) -> bool
pub fn high_density(&self) -> bool
Check if the highDensity feature is supported.
Sourcepub fn paper_full_cut(&self) -> bool
pub fn paper_full_cut(&self) -> bool
Check if the paperFullCut feature is supported.
Sourcepub fn paper_part_cut(&self) -> bool
pub fn paper_part_cut(&self) -> bool
Check if the paperPartCut feature is supported.
Sourcepub fn pdf417_code(&self) -> bool
pub fn pdf417_code(&self) -> bool
Check if the pdf417Code feature is supported.
Sourcepub fn pulse_standard(&self) -> bool
pub fn pulse_standard(&self) -> bool
Check if the pulseStandard feature is supported.
Sourcepub fn star_commands(&self) -> bool
pub fn star_commands(&self) -> bool
Check if the starCommands feature is supported.
Sourceimpl Features
impl Features
Sourcepub fn with_barcode_a(self, on: bool) -> Self
pub fn with_barcode_a(self, on: bool) -> Self
Set the barcodeA feature to be on or off.
Sourcepub fn with_barcode_b(self, on: bool) -> Self
pub fn with_barcode_b(self, on: bool) -> Self
Set the barcodeB feature to be on or off.
Sourcepub fn with_bit_image_column(self, on: bool) -> Self
pub fn with_bit_image_column(self, on: bool) -> Self
Set the bitImageColumn feature to be on or off.
Sourcepub fn with_bit_image_raster(self, on: bool) -> Self
pub fn with_bit_image_raster(self, on: bool) -> Self
Set the bitImageRaster feature to be on or off.
Sourcepub fn with_graphics(self, on: bool) -> Self
pub fn with_graphics(self, on: bool) -> Self
Set the graphics feature to be on or off.
Sourcepub fn with_high_density(self, on: bool) -> Self
pub fn with_high_density(self, on: bool) -> Self
Set the highDensity feature to be on or off.
Sourcepub fn with_paper_full_cut(self, on: bool) -> Self
pub fn with_paper_full_cut(self, on: bool) -> Self
Set the paperFullCut feature to be on or off.
Sourcepub fn with_paper_part_cut(self, on: bool) -> Self
pub fn with_paper_part_cut(self, on: bool) -> Self
Set the paperPartCut feature to be on or off.
Sourcepub fn with_pdf417_code(self, on: bool) -> Self
pub fn with_pdf417_code(self, on: bool) -> Self
Set the pdf417Code feature to be on or off.
Sourcepub fn with_pulse_bel(self, on: bool) -> Self
pub fn with_pulse_bel(self, on: bool) -> Self
Set the pulseBel feature to be on or off.
Sourcepub fn with_pulse_standard(self, on: bool) -> Self
pub fn with_pulse_standard(self, on: bool) -> Self
Set the pulseStandard feature to be on or off.
Sourcepub fn with_qr_code(self, on: bool) -> Self
pub fn with_qr_code(self, on: bool) -> Self
Set the qrCode feature to be on or off.
Sourcepub fn with_star_commands(self, on: bool) -> Self
pub fn with_star_commands(self, on: bool) -> Self
Set the starCommands feature to be on or off.