escpos_db

Struct OwnedIntMap

source
pub struct OwnedIntMap<T> { /* private fields */ }
An owned version of IntMap.

Implementations

source

impl<T> OwnedIntMap<T>

source

pub fn insert(&mut self, key: u8, val: T) -> Option<T>

Insert a new entry into the map, returning the previous value at key if it existed.

Methods from Deref<Target = IntMap<T>>

source

pub fn get(&self, k: u8) -> Option<&T>

Lookup a value by the given key.

source

pub fn iter(&self) -> IntMapIter<'_, T>

Returns an iterator over the entries of this map.